0.10.21 UPD 28 ago Windows, Linux

Download Team Red Miner

TeamRedMiner — Guida completa

Opzioni:

  -a, --algo=ALGORITHM      Sceglie l'algoritmo di mining.  Attualmente disponibili:
                              ethash            (eth, etp, altre)
                              etchash           (etc, alias di -a ethash --eth_variant_mode=etchash)
                              kawpow            (ravencoin)
                              firopow           (firo)
                              mtp_firopow       (sceglie firopow o mtp e chiude il miner al fork del 26 ottobre 2021)
                              autolykos2        (ergo)
                              verthash          (vtc)
                              ton               (ton)
                              kas               (kaspa)
                              nimiq             (nimiq)
                              lyra2z
                              phi2              (lux, argoneum)
                              lyra2rev3
                              x16r
                              x16rv2
                              x16s              (pgn, xsh)
                              x16rt             (gin)
                              mtp               (zcoin/firo prima del fork firopow)
                              cuckatoo31_grin   (grin)
                              cuckarood29_grin  (grin)
                              cnv8
                              cnr               (vecchio monero)
                              cnv8_half         (stellite, masari)
                              cnv8_dbl          (x-cash)
                              cnv8_rwz          (graft)
                              cnv8_trtl         (vecchio turtlecoin, loki)
                              cnv8_upx2         (uplexa)
                              cn_heavy          (CN heavy classico)
                              cn_haven          (haven)
                              cn_saber          (bittube)
                              cn_conceal        (conceal)
                              trtl_chukwa       (turtlecoin)
                              trtl_chukwa2      (turtlecoin)

  -h, --help                Mostra questo messaggio di aiuto ed esce.
      --debug               Attiva l'output di log di debug.
      --hardware=HW_LIST    Indica su quali tipi di hardware il miner deve provare a funzionare, in un elenco separato da virgole.
                              I valori attualmente supportati sono 'gpu' e 'fpga'.  Ad esempio:
                                --hardware=gpu,fpga
      --benchmark           Attiva la modalità benchmark.  Tutti i pool definiti vengono ignorati e viene aggiunto automaticamente
                              un unico pool interno fittizio.  Per fare il benchmark di algoritmi come eth e kawpow a epoche e altezze
                              di blocco specifiche devi aggiungere anche argomenti specifici dell'algoritmo come --eth_epoch=456 e --prog_height=123456.
      --disable_colors      Disattiva i colori nell'output della console.
      --force_colors        Forza l'output a colori nella console anche se il terminale sembra non supportarli.
      --api_listen=IP:PORT  Attiva l'api compatibile con sgminer. IP:PORT è facoltativo. Se presente, la combinazione IP:PORT
                              decide l'interfaccia (o le interfacce) e la porta di ascolto. Il predefinito è 127.0.0.1:4028. Per
                              l'accesso esterno usa ad es. 0.0.0.0:4028. È valido anche indicare solo la
                              porta, ad es. 4029.  Ora è possibile indicare più volte questo argomento per endpoint separati.
      --api2_listen=IP:PORT Attiva una seconda porta api per le configurazioni di dual mining.  Questo endpoint api fornisce i dati per
                              l'algoritmo di dual mining, proprio come se due istanze separate del miner girassero in parallelo.  Il
                              valore predefinito è 127.0.0.1:4029, cioè la porta è 4029 e non 4028.  Per indicare una scelta
                              personalizzata, l'argomento ha lo stesso formato di --api_listen.  Ora è possibile indicare più volte questo argomento
                               per endpoint separati.
      --cm_api_listen=IP:PORT Attiva l'api compatibile con claymore. IP:PORT è facoltativo. Se presente, la combinazione IP:PORT
                              decide l'interfaccia (o le interfacce) e la porta di ascolto. Il predefinito è 127.0.0.1:3333. Per
                              l'accesso esterno usa ad es. 0.0.0.0:3333. È valido anche indicare solo la
                              porta, ad es. 3334.
      --cm_api_password=PSW Imposta la password richiesta per l'interfaccia api compatibile con CM.
      --log_file(=FILENAME) Attiva la scrittura dell'output del miner nel file indicato da FILENAME.  Se non viene indicato
                              alcun nome di file, il miner scrive il log in trm_<algo>_<yyyymmdd_hhmmss>.log nella cartella
                              di lavoro corrente.  Se il file di log esiste già, il miner lo aggiunge in coda.
  -l, --log_interval=SEC    Imposta l'intervallo di tempo in secondi per il calcolo della media e la stampa dell'hashrate delle GPU.
                              SEC imposta l'intervallo in secondi e deve essere > 0.
      --log_rotate=SZ[,CNT] Attiva la rotazione dei log. Il valore SZ imposta la dimensione del log oltre la quale viene creato
                              un nuovo file di log.  Il valore SZ supporta i suffissi 'k', 'M' e 'G', che moltiplicano il
                              valore rispettivamente per 1024, 1048576 e 1073741824. Il valore facoltativo CNT imposta il
                              numero massimo di vecchi file di log da conservare.  Ad esempio l'opzione '--log_rotate=4M,16'
                              fa passare il miner a un nuovo file di log quando quello attuale supera
                              4194304 byte, e il miner conserva gli ultimi 16 file di questo tipo ed elimina
                              quelli più vecchi.
      --short_stats         Disattiva l'output completo dello stato delle gpu in ogni output dell'hashrate, come prima della 0.7.10.
      --dev_location=LOC    Sceglie una località specifica per la connessione della commissione dello sviluppatore. Usalo solo se il miner
                              segnala continui problemi di connessione per la commissione. La gestione della connessione
                              di solito funziona bene in tutte le località. Le opzioni disponibili sono:
                              world     - Qualsiasi parte del mondo tranne la Cina continentale.
                              non-gcp   - Paesi con accesso bloccato ai servizi Google (ad es. Iran, Cuba).
                              cn        - Cina continentale.
                              eu        - UE, Russia, Ucraina e dintorni.
                              us        - USA, Canada, America centrale/meridionale.
                              asia      - Asia esclusa la Cina.
      --enable_compute      (Solo Windows) Attiva la modalità compute e disattiva crossfire sulle gpu dove serve.
      --long_timestamps     Attiva nei log timestamp in microsecondi invece che solo in secondi.
      --restart_gpus        (Solo Windows) Riavvia tutte le gpu configurate prima del mining, cioè disattiva+attiva il dispositivo PCI.
      --uac                 (Solo Windows) Attiva l'elevazione dei privilegi quando il miner esegue operazioni come il riavvio delle gpu.
                              Puoi sempre evitarlo avviando il miner direttamente come Amministratore.  Questo
                              attiva la richiesta standard di elevazione di Windows, quindi devi essere presente per fare clic su 'Sì'.
                              Se non è attivo, le operazioni che richiedono privilegi di Amministratore falliscono quando il
                              miner gira con un account utente normale.
      --high_score          Attiva la stampa nelle statistiche delle 15 migliori share trovate dall'avvio del miner.
                              Nota: potrebbe non essere attivo per tutti gli algoritmi.
      --allow_dup_bus_ids   Consente a più gpu di usare lo stesso pci bus id.  Va usato solo per le schede Radeon Pro Duo
                              e hardware simile; di solito indica un ambiente OpenCL non funzionante.
      --dns_https=URL       Attiva la risoluzione DNS dei pool tramite DNS-over-HTTPS.  È una funzione sperimentale.  TRM supporta
                              solo la variante basata su JSON, non il meccanismo definito in seguito nella RFC8484.  L'utente deve
                              fornire l'url https completo, incluso il nome del metodo.  È consentito passare hostname
                              invece di indirizzi IP, ma questi hostname verranno risolti con il DNS di sistema.
                              Ecco alcuni esempi di cui è stato verificato il funzionamento:

                              --dns_https=https://8.8.8.8/resolve           (Google DNS)
                              --dns_https=https://9.9.9.9:5053/dns-query    (Quad9)
                              --dns_https=https://1.1.1.1/dns-query         (servizio DNS di Cloudflare)
      --dns_https_sni=HOST  Quando si usa l'argomento --dns_https, per default non viene inviato alcun SNI nella
                              connessione SSL/TLS.  Con questo argomento puoi forzare l'invio di qualsiasi SNI.  Nota
                              che è un argomento di rete avanzato e la maggior parte degli utenti non ne ha bisogno.
      --kernel_vm_mode=X    (Solo Linux). Automatizza l'impostazione dei parametri del kernel necessari in /etc/default/grub sui sistemi
                              Linux basati su Debian/Ubuntu.  Questo copre la maggior parte delle distribuzioni per il mining.  Il sistema può
                              essere riavviato automaticamente con /sbin/reboot quando i parametri del kernel vengono modificati.  Se i
                              parametri corretti sono già presenti, il miner e lo script di supporto non fanno nulla. Questo significa che
                              questo argomento può essere sempre presente nella riga di comando.  I valori validi sono:
                                N  -  nessuna modalità configurata, rimuove i parametri esistenti per la modalità C o R.  Nessun riavvio in caso di modifica.
                                C  -  vecchia modalità C della Radeon VII.  Nessun riavvio in caso di modifica.
                                R  -  nuova modalità R per tutte le gpu tranne Polaris.  Nessun riavvio in caso di modifica.
                                RN -  nessuna modalità configurata, rimuove i parametri esistenti per la modalità C o R.  Riavvia in caso di modifica.
                                RC -  vecchia modalità C della Radeon VII.  Riavvia in caso di modifica.
                                RR -  nuova modalità R per tutte le gpu tranne Polaris.  Riavvia in caso di modifica.
      --kernel_vm_mode_script=X  (Solo Linux).  Indica lo script da richiamare per impostare i nuovi parametri della modalità del kernel.
                              Lo script deve comportarsi come lo script TRM predefinito incluso nel pacchetto di distribuzione del miner,
                              chiamato ubuntu_mode_script.sh.  Normalmente questo argomento non dovrebbe essere necessario.
      --gpu_sdma=on|off     Controlla se il driver usa operazioni sdma dirette per copiare la memoria da/verso
                              la gpu. Questo argomento serve solo in situazioni molto particolari. Ad esempio, l'AMD BC-250
                              non supporta sdma e richiede --gpu_sdma=off. Se il miner si blocca subito all'inizializzazione
                              delle gpu, ma altri miner o versioni più vecchie di TRM funzionano bene, prova --gpu_sdma=off.
                              Questa impostazione è un'impostazione d'ambiente e controlla tutte le gpu.

Opzioni di configurazione del pool:

  -o, --url=URL             Imposta l'URL del pool.  Attualmente sono supportati gli URL stratum+tcp e stratum+ssl.
                              Ogni volta che questa opzione viene indicata di nuovo, inizia una nuova configurazione di pool.
                              Le opzioni per singolo pool (come -u, -p) vanno indicate di nuovo esplicitamente
                              per ogni nuovo pool.  (Vedi il file di esempio start_multipool.sh/bat)
                              La strategia multi-pool del miner si imposta con l'opzione --pool_strategy.
                              C'è anche un supporto speciale per configurazioni SSL/TLS avanzate in cui devi
                              passare un hostname SNI all'endpoint SSL. Ad esempio, serve per gli endpoint SSL
                              che fanno da frontend per più host e devono sapere per quale di essi
                              fornire il certificato. In questi casi usa il formato seguente:
                              -o stratum+ssl://pool.tunnel.com/pool.realhostname.com:3333
                              Si connetterà a pool.tunnel.com:3333, ma passerà pool.realhostname.com come hostname
                              SNI nella fase di handshake SSL. Ovviamente i due hostname possono anche essere identici.
  -u, --user=USERNAME       Imposta il nome utente per l'autorizzazione sul pool.
  -p, --pass=PASSWORD       Imposta la password per l'autorizzazione sul pool.
      --pool_force_ensub    Forza una richiesta di extranonce subscribe per i pool supportati ma sconosciuti al miner.
      --pool_no_ensub       Impedisce al miner di inviare al pool la richiesta di extranonce subscribe.
      --pool_broken_rpc     Indica al miner di consentire una sola richiesta rpc in sospeso sulla connessione
                              al pool.  È una soluzione per i pool che violano la specifica json rpc
                              riguardo agli ID rpc.
      --pool_ratio=RATIO    Imposta il rapporto di hashrate tra i pool quando si usano più pool con le strategie
                              'load_balance' o 'quota' (vedi --pool_strategy).  Per default tutti
                              i pool usano il rapporto 1.  Ad esempio, usando questa opzione con il valore 2
                              su un solo pool, quel pool riceverà il doppio dell'hashrate rispetto agli altri,
                              perché il loro rapporto resterà il valore predefinito 1.
      --pool_debug          Registra nel log tutto il traffico con il pool.

Opzioni globali dei pool:

      --pool_connect_TO=SEC Imposta il timeout per i tentativi di connessione a un pool. SEC è il tempo di attesa in
                              secondi. Il valore predefinito è 10.
      --pool_rpc_TO=SEC     Imposta quanto a lungo il miner attende una RPC al pool senza risposta.  Trascorso questo
                              tempo, il miner si riconnette al pool.  SEC è il tempo di attesa in secondi.
                              Il valore predefinito è 60.
      --pool_max_rejects=N  Se un pool rifiuta N share di seguito, la connessione al pool viene reimpostata. Serve a proteggersi
                              dai pool che invalidano le sessioni di mining senza disconnettere l'utente.
                              Il valore predefinito è 5.
      --pool_share_limit_ms=N  Se un pool impiega più di N ms per accettare o rifiutare una share, chiude la connessione
                              attuale e si riconnette.  È pensato per i pool che hanno spesso problemi con
                              alcuni dei loro server: riconnettersi significa essere bilanciati su un server diverso e,
                              si spera, migliore.  Per default non c'è timeout.
      --pool_strategy=STRAT Imposta la strategia di scelta dei pool quando si lavora con più pool.  I valori
                              disponibili sono: priority, load_balance, quota e min_epoch.  Il valore predefinito è priority.
                              priority: il miner usa i pool nell'ordine in cui sono elencati e passa
                                al pool successivo solo se il precedente non riesce a stabilire una connessione.
                              load_balance: il miner distribuisce uniformemente l'hashrate su tutti i pool
                                attualmente connessi.  Il rapporto di hashrate tra i pool si imposta con --pool_ratio.
                              quota: il miner distribuisce uniformemente il totale degli hash completati su
                                tutti i pool.  Se un pool si disconnette e poi si riconnette, il miner sposta
                                hashrate su quel pool finché il totale degli hash di ogni pool non è bilanciato.
                                Il rapporto di hashrate tra i pool si imposta con --pool_ratio.
                              min_epoch: strategia di passaggio ETH + ZIL.  Il miner mina sempre l'epoca più bassa
                                tra tutti i pool connessi e, in caso di parità, il primo pool connesso.
                                Quindi indica il tuo pool di mining ETH come primo pool/principale, poi il pool ZIL
                                come secondo pool.  Per questa strategia puoi usare anche il nome 'eth_zil'.
      --no_ntime_roll       Impedisce al miner di modificare ntime nell'header del blocco, usando solo il valore
                              fornito dal pool. Per alcuni pool va attivato quando si mina x16rt.
      --no_stale_submit     Impedisce al miner di inviare share che non riguardano il job più recente del pool.

Opzioni delle GPU:

      --platform=INDEX      Imposta l'indice della piattaforma OpenCL da usare. Se non è indicato, la piattaforma viene
                              rilevata automaticamente. Su Linux con più piattaforme è supportato solo non usare
                              l'argomento --platform e aggiungere invece --bus_reorder.
  -d, --devices=DEVLIST     Imposta i dispositivi gpu da usare tra quelli rilevati. DEVLIST deve essere un elenco di indici
                              di dispositivi separati da virgole, ad es. -d 0,1,2,4.  Se non è indicato, vengono usati tutti
                              i dispositivi della piattaforma (o delle piattaforme).  NOTA: per default i dispositivi sono ordinati
                              secondo l'ordine del bus pcie. Usa --list_devices per vedere gli indici.
      --init_style=1/2/3    Indica lo stile di inizializzazione (1 è il predefinito):
                              1: Una gpu alla volta, completa tutte prima di minare.
                              2: Tre gpu alla volta, completa tutte prima di minare.
                              3: Tutte le gpu in parallelo, inizia subito a minare.
      --pcie_fmt=FORMAT     Imposta il formato di stampa dei numeri del bus pcie.  I valori accettati per FORMAT sono
                              'hex' o 'dec'.  Il predefinito è dec per windows e hex per linux.
      --bus_reorder         Riordina i dispositivi rilevati o indicati in base al loro pcie bus id.  Se non è
                              indicata alcuna piattaforma, i dispositivi vengono raccolti da tutte le piattaforme AMD OpenCL
                              rilevate.  Nota: dalla versione v0.7.0 questo è il comportamento predefinito.
      --opencl_order        Ordina i dispositivi rilevati o indicati nell'ordine in cui li presenta OpenCL.
      --list_devices        Elenca i dispositivi disponibili per la piattaforma rilevata o indicata ed esce
                              subito.  Il riordino per bus viene applicato all'ordine mostrato.
      --nr_cu_override=X,Y,... Sostituisce il numero di compute unit per gpu presentato dall'API OpenCL. È
                              utile soprattutto per le Vega 64 flashate con il bios della 56, per cui il driver
                              riporta 56 CU invece del numero reale.  Come valore dell'argomento fornisci un elenco separato da virgole
                              del numero di CU da sostituire per ogni gpu.  Puoi saltare delle gpu e non
                              serve fornire valori per tutte le gpu del rig.  Esempio per un rig misto con due Vega
                              agli indici 1 e 3 e altre due gpu: --nr_cu_override=,64,,64.  Puoi verificare il tuo
                              argomento aggiungendo anche --list_devices prima di minare.

Opzioni di controllo di frequenze/tensioni (solo windows, funzione BETA):

                              Il miner ha funzioni di base per impostare le frequenze del core e della memoria e le relative
                              tensioni, oltre a scegliere tra i timing integrati del driver windows.  Per ogni
                              argomento disponibile qui sotto, elenchi i valori per le gpu del rig in un elenco separato
                              da virgole.  Alcuni argomenti non si usano per certe gpu.  Puoi saltare gpu nell'elenco.
                              Il miner imposta e usa sempre il p-state più alto sia per il core sia per la memoria sulle gpu GCN
                              (Polaris, Vega).  Nota che le gpu Rx Vega _devono_ avere una modifica della powerplay table
                              per il p2 state della memoria prima di poter funzionare con una tensione inferiore a 900mV.  Inoltre, anche le gpu
                              Big Navi devono ancora usare ad es. MorePowerTool per modificare la powerplay table, ad esempio
                              per poter impostare una tensione più bassa.  In futuro il miner _potrebbe_ aggiungere il supporto per le funzioni
                              legate alla powerplay table.
      --clk_debug                 Attiva all'avvio le stampe nel log relative all'impostazione di frequenze/tensioni/timing.
      --clk_core_mhz=MHZ1,MHZ2,... Imposta la frequenza del core per ogni gpu in MHz.
      --clk_core_mv=MV1,MV2,...    Imposta la tensione del core per ogni gpu in mV.
      --clk_mem_mhz=MHZ1,MHZ2,...  Imposta la frequenza della memoria per ogni gpu in MHz.
      --clk_mem_mv=MV1,MV2,...     Imposta la tensione della memoria per ogni gpu in mV.  Non si usa per le gpu Navi o Big Navi.
      --clk_timing=V1,V2,...       Sceglie tra i set di timing della memoria disponibili nel driver.  Non disponibile su tutte le gpu e
                                   tutti i driver.
                              Esempio di riga di comando parziale per un sistema con quattro gpu, una Rx Vega 64, una 580, una 5700XT e una
                              6800, che minano ethash o simili.   Indichiamo la tensione della memoria solo per la Vega e la 580, e scegliamo
                              un valore di timing del driver solo per la Big Navi:
                              teamredminer.exe ... --clk_core_mhz=1100,1000,1275,1000 --clk_core_mv=875,850,725,675
                              --clk_mem_mhz=1107,2100,1820,2130 --clk_mem_mv=875,850,, --clk_timing=,,,1

Opzioni di controllo delle ventole:

      --fan_control(=CFG1,CFG2,...)  Questo argomento attiva il controllo delle ventole delle gpu da parte del miner.  TRM supporta
                              la regolazione automatica della velocità delle ventole in base alla temperatura del core, della junction e/o della memoria.
                              Supportiamo anche l'impostazione di una velocità fissa delle ventole in percentuale.
                              Ogni tipo di gpu ha una configurazione delle ventole usata per default.  Supportiamo
                              sia la sostituzione della configurazione predefinita per tipo di gpu sia l'impostazione di una
                              configurazione specifica per ogni gpu del rig.
                              Una configurazione delle ventole è composta da (al massimo) sei valori, separati dal carattere ':' (due punti).  I valori
                              sono: temperatura obiettivo del core, temperatura obiettivo della junction, temperatura obiettivo della memoria, velocità iniziale della ventola in
                              percentuale, velocità minima della ventola in percentuale, velocità massima della ventola in percentuale.  Qualsiasi valore può essere lasciato vuoto.
                              Ecco alcuni esempi:
                              ::70:50:25   Temperatura obiettivo della memoria 70C, ventola che parte al 50%, velocità minima 25%.
                              55::::20:80  Temperatura obiettivo del core 55C, ventola che parte alla velocità della configurazione predefinita,
                                           ventola sempre tra il 20% e l'80%.
                              55::75:80    Regola la ventola in modo che la temperatura del core sia <= 55C e quella della memoria <= 75C, con la
                                           ventola che parte all'80%.
                              :::100       Imposta una velocità fissa della ventola al 100%, senza mai regolarla in base alle temperature.
                              La configurazione delle ventole usata per una gpu viene determinata con il seguente ordine di precedenza:
                              1. All'argomento --fan_control è stato passato un elenco di configurazioni che include una
                                 voce per la gpu X.
                              2. La configurazione predefinita delle ventole per questo tipo di gpu è stata sostituita con un
                                 parametro --fan_default_<type>=....
                              3. Si usa la configurazione predefinita integrata delle ventole per questo tipo di gpu.
                              Nell'elenco qui sopra, se nella configurazione scelta manca il valore iniziale della ventola,
                              si usa l'impostazione della configurazione successiva.
                              NOTA: il supporto delle ventole è una funzione beta e non funzionerà meglio del supporto fornito dai
                              driver.  Ad esempio, spesso i driver su linux non permettono di forzare una
                              ventola al 100% tramite il supporto pwm di sysfs.
      --fan_default_polaris=CFG Imposta la configurazione predefinita usata per tutte le gpu Polaris (450/460/550/560/470/480/570/580/590).
                              Il predefinito integrato è 55:::50, cioè temperatura del core 55C e ventola che parte al 50%.
                              Nota: questa impostazione viene riutilizzata anche per le gpu Tonga.
      --fan_default_vega=CFG    Imposta la configurazione predefinita usata per tutte le gpu Vega (Vega 56/Vega 64).
                              Il predefinito integrato è 55::70:50, cioè temperatura del core 55C, della memoria 70C e ventola al 50%.
      --fan_default_vega2=CFG   Imposta la configurazione predefinita usata per tutte le gpu Radeon VII.
                              Il predefinito integrato è 70::75:80, cioè temperatura del core 70C, della memoria 75C e ventola all'80%.
      --fan_default_navi=CFG    Imposta la configurazione predefinita usata per tutte le Navi (Navi10).
                              Il predefinito integrato è 60::80:70, cioè temperatura del core 60C, della memoria 80C e ventola al 70%.
      --fan_default_big_navi=CFG  Imposta la configurazione predefinita usata per tutte le Big Navi (Navi21).
                              Il predefinito integrato è 50:::70, cioè temperatura del core 50C e ventola al 70%. La temperatura della memoria
                              non è inclusa perché nella libreria ADL di Windows manca il sensore.
      --fan_debug             Attiva le stampe nel log relative alle regolazioni.
      --fan_no_restore        Disattiva il ripristino dei profili originali delle ventole all'uscita dal miner.

Opzioni del watchdog:

      --no_gpu_monitor      Disattiva il monitor delle GPU ADL (Windows) o sysfs (Linux) per la temperatura e la
                              velocità delle ventole.
      --temp_limit=TEMP     Imposta la temperatura del core alla quale il miner ferma le GPU troppo calde.
                              Il predefinito è 85C.  Si possono fornire valori specifici per gpu con un elenco separato da virgole,
                              un valore per gpu.  Se una gpu non ha un valore definito, si usa il primo valore
                              dell'elenco.
      --temp_resume=TEMP    Imposta la temperatura del core sotto la quale il miner riavvia le GPU fermate in precedenza
                              perché la temperatura del core aveva superato il limite.  Il predefinito è 60C.  Si possono fornire
                              valori specifici per gpu con un elenco separato da virgole, un valore per gpu.  Se una gpu non
                              ha un valore definito, si usa il primo valore dell'elenco.
      --mem_temp_limit=TEMP Imposta la temperatura della memoria alla quale il miner ferma le GPU troppo calde.
                              Per default non è attivo.  Si usa solo se la gpu ha un sensore di temperatura della memoria.
                              Si possono fornire valori specifici per gpu con un elenco separato da virgole, un valore per gpu.
                              Se una gpu non ha un valore definito, si usa il primo valore dell'elenco.
      --mem_temp_resume=TEMP Imposta la temperatura della memoria sotto la quale il miner riavvia le GPU fermate in precedenza
                              perché la temperatura della memoria aveva superato il limite.  Per default non è attivo.  Si
                              usa solo se la gpu ha un sensore di temperatura della memoria.  Si possono fornire valori specifici per gpu
                              con un elenco separato da virgole, un valore per gpu.  Se una gpu non ha un valore definito,
                              si usa il primo valore dell'elenco.
      --watchdog_script(=X) Configura il watchdog delle gpu per chiudere il miner ed eseguire lo script della piattaforma indicato,
                              poi esce immediatamente. Lo script predefinito è watchdog.bat/watchdog.sh nella
                              cartella corrente, ma si può indicare uno script diverso come argomento facoltativo,
                              eventualmente anche con un percorso assoluto o relativo.
      --watchdog_test       Verifica lo script del watchdog configurato attivando la stessa azione di una gpu morta
                              dopo ~20 secondi di mining.
      --watchdog_disabled   Impedisce l'esecuzione del watchdog. Si può usare per disattivare il watchdog nei sistemi operativi di mining
                              che girano sempre con il watchdog attivo.

Opzioni di Ethash:

      --eth_config=CONFIG   Configurazione manuale di ethash per il miner.  CONFIG deve essere nella forma [X][M][L].
                              Il valore [M] sceglie la modalità, che può essere 'A','B' o 'C'.
                              La modalità 'B' usa memoria aggiuntiva e funziona solo su schede da 8+GB.
                              La modalità 'C' usa memoria aggiuntiva e funziona solo su schede da 16+GB, come la VII, con
                              un sistema configurato correttamente.  Per maggiori dettagli vedi ETHASH_TUNING_GUIDE.txt.
                              Il valore [L] sceglie l'intensità e il suo intervallo dipende dall'architettura della GPU.
                              Il prefisso [X] è facoltativo ed è solo per Navi/Big Navi: attiva più operazioni sulla memoria e
                              porta a un valore di regolazione [L] più basso. Può essere utile quando l'auto-tuner raggiunge ripetutamente
                              un valore vicino al massimo valore di regolazione possibile per la gpu.
                              Entrambi i valori sono facoltativi, ma se si indica [L], va indicato anche [M].
                              Configurazioni di esempio: --eth_config=A
                                               --eth_config=B750
                                               --eth_config=XB
                              CONFIG può anche essere un elenco di valori di configurazione separati da virgole, ciascuno
                              applicato a ogni GPU. Ad esempio: --eth_config=A,B750,,A288
                              Ogni gpu che non ha una configurazione specifica nell'elenco usa la prima
                              configurazione dell'elenco.
      --eth_variant_mode=X  Questo argomento controlla l'attivazione delle modifiche a ethash per ETC dall'epoca 390, come descritto
                              nella ecip-1099. Sono disponibili le seguenti modalità:
                              pool      - Modalità predefinita. Si attiva solo se il pool invia un flag di algoritmo che contiene etchash.
                                          Quando viene visto questo flag, tutti i job del pool sono considerati etchash, a meno che non
                                          arrivi un altro flag di algoritmo che contiene ethash.
                              etchash   - Modalità etchash. Le epoche >= 390 sono considerate etchash, quelle inferiori ethash. I flag
                                          di algoritmo del pool non vengono usati.
                              deduce    - Ignora i flag di algoritmo del pool e applica solo un'euristica basata sull'ora attuale del sistema
                                          e sulle altezze e i tempi noti di ETC ed ETH. Questa modalità dovrebbe funzionare come approccio
                                          generico quando ETH raggiunge l'epoca 390 a gennaio 2021. L'orologio di sistema deve essere corretto.
                                          Dovrebbe gestire anche le configurazioni di profit switching che passano liberamente tra job ethash ed
                                          etchash facendo da proxy ai pool sottostanti.
                              auto      - Finché il pool non ha inviato un flag di algoritmo, usa la modalità deduce. Quando viene visto un flag
                                          di algoritmo, passa alla modalità pool.
                              ethash    - Modalità ethash forzata. Non applica mai la ecip-1099.
                              force_etc - Modalità etchash forzata. Applica sempre le regole della ecip-1099. Da usare per il mining sulla testnet di ETC.
      --eth_aggr_mode       Attiva l'uso automatico della modalità 'B' per tutte le schede Polaris da 8GB, a meno che non abbiano
                              una configurazione diversa fornita con l'argomento --eth_config.  Equivale a
                              impostare manualmente in modalità 'B' tutte le gpu Polaris da 8GB del rig con --eth_config.
                              Per la maggior parte delle gpu aggiunge 0.1-0.2 MH/s di hashrate.  NOTA: il 20-25% dei rig diventa meno
                              stabile in questa modalità, ed è per questo che non è la modalità predefinita.  Se hai
                              gpu morte, rimuovi questo argomento e fai girare le gpu in modalità 'A'.
      --eth_stratum_mode=MODE Imposta una modalità stratum fissa per i pool ethash.  Per default il miner cerca
                              di determinare automaticamente il tipo di stratum supportato dal pool e usa quella modalità.
                              Questo rilevamento automatico può essere sostituito indicando questa opzione.  MODE può essere
                              impostato su una delle seguenti opzioni: stratum, nicehash, ethproxy.
      --eth_worker          Imposta l'id del worker che viene inviato al pool.  Vale solo per i pool con modalità stratum
                              ethproxy.
      --eth_hash_report=X   Controlla i report dell'hashrate verso i pool configurati.  Questo valore si applica a tutti i pool. Valori:
                              default   - lascia decidere al miner in base al protocollo stratum usato per ogni pool.
                              force     - invia sempre i report dell'hashrate, anche se il pool li rifiuta.
                              on        - invia un primo report dell'hashrate e lo disattiva per i pool che rifiutano il messaggio.
                              off       - non invia mai report dell'hashrate.
      --eth_epoch           Prova un'epoca ethash specifica. NOTA: il miner passa automaticamente in modalità benchmark, come
                              se avessi aggiunto --benchmark.
      --eth_alloc_epoch=N   Alloca fin dall'inizio memoria sufficiente per l'epoca indicata.  Se in seguito ne servirà di più
                              durante il mining, il miner proverà ad allocarne altra.
      --eth_dag_buf=X,Y,... Il miner può allocare un buffer singolo o doppio per il DAG.  Per ora il predefinito è AUTO.  Un buffer
                              singolo è leggermente migliore e porta a un piccolo risparmio energetico su tutti i tipi di gpu.  Solo i driver recenti supportano
                              allocazioni singole superiori a 4GiB, in genere da Adrenalin 20.9.1 e amdgpu-pro 20.x. Con questo argomento il miner
                              può usare automaticamente la modalità a buffer singolo quando possibile, oppure forzare buffer singoli o doppi
                              per gpu.  I valori supportati sono A(uto), S(ingle), D(ual).  Puoi indicare un elenco separato da virgole
                              per tutte le gpu del rig, o un solo valore per tutte le gpu.  Una gpu che non ha un valore nell'elenco
                              separato da virgole usa il primo valore.
      --eth_big_mode_adjust=X,Y,...  Con le modalità B o C, il miner funziona meglio quanta più vram riesce ad allocare.  Purtroppo i
                              driver non riportano con precisione quanta memoria è possibile allocare, soprattutto su Windows.
                              Il miner usa un valore prudente e sicuro di 256MiB (Linux) e 512MiB (Windows) come offset rispetto
                              alla vram disponibile.  Se vuoi cambiare questo valore, puoi farlo con questo argomento fornendo
                              un elenco separato da virgole con i valori per una o più gpu.  I valori per le gpu che non usano la modalità B/C vengono
                              ignorati.  Se una gpu non ha un valore nell'elenco, si usa invece il primo valore fornito.
                              L'intervallo consentito è [-64, 2048]. Più alto è il valore, meno vram viene allocata sulla gpu.
      --eth_dag_slowdown=N  Rallenta la generazione del DAG.  Passa una sola cifra da 0 a 9. 0 significa nessun rallentamento (comportamento <= 0.7.9),
                              1 significa rallentamento minimo, 9 massimo.  Valore predefinito: 4, per un leggero rallentamento.
      --eth_stagger         Attiva l'avvio scaglionato delle gpu quando si costruisce un nuovo DAG.  È più leggero per gli alimentatori che non sopportano
                              il passaggio dallo 0 al 100% di carico su tutte le gpu nello stesso momento.
      --eth_no_stagger      Disattiva --eth_stagger.  È già il comportamento predefinito dalla 0.7.18.  L'argomento è mantenuto solo per
                              compatibilità con le versioni precedenti.
      --eth_ramp_up         Aggiunge un aumento graduale dell'intensità su tutte le gpu dopo la costruzione del DAG, la disattivazione/attivazione di una gpu o un'interruzione di rete.
                              Può aiutare i rig che vanno in crash proprio tra la costruzione del DAG e l'inizio del mining.
      --eth_no_ramp_up      Disattiva --eth_ramp_up.  È già il comportamento predefinito dalla 0.7.18.  L'argomento è mantenuto solo per
                              compatibilità con le versioni precedenti.
      --eth_direct_abort    Usa un meccanismo diverso per interrompere i job in corso sulle gpu.  Consigliato per le Vega in ambienti ROCm
                              per ridurre al minimo le share obsolete.  Si applica solo alle gpu Vega e Polaris del rig.
      --eth_dag_alloc_patch Alcune schede madri con bios obsoleto possono avere errori hw, di solito sulla prima o sull'ultima gpu del sistema.
                              Usa questo argomento per forzare una strategia di allocazione del dag modificata che il più delle volte risolve il problema.
                              Anche l'aggiornamento del bios spesso risolve il problema.
      --eth_hashwatch(=M,M) Definisce un hashrate minimo/massimo in MH/s atteso dal watchdog quando le gpu calcolano hash.  Se una GPU resta fuori
                              da questo intervallo troppo a lungo, viene considerata guasta e il watchdog viene attivato.  I
                              valori min/max predefiniti sono 2 MH/s e 150 MH/s.  Per attivarlo con i valori predefiniti usa
                              --eth_hashwatch.  Per impostare valori personalizzati usa ad es. --eth_hashwatch=1.25,60.  Lo stesso intervallo vale
                              per tutte le gpu del rig.  Un valore negativo per un lato lo disattiva, ad es. usa --eth_hashwatch=-1,1000
                              per gestire i reset delle gpu che producono hashrate fittizi enormi, ma senza controllo del minimo.
      --eth_dag_cache(=EPOCH) Attiva il salvataggio dei DAG eth dei job con epoche diverse, per non doverli ricostruire in
                              futuro se arrivano di nuovo job con le vecchie epoche.  Viene salvato al massimo un DAG, se la memoria della GPU
                              lo consente.  È utile per i pool che alternano, come il mining eth+zil.  Se vuoi precostruire una
                              certa epoca subito all'avvio, aggiungi il valore facoltativo. I miner che alternano eth+zil dovrebbero usare
                              --eth_dag_cache=0.  Al momento si possono precostruire solo epoche ethash (non etchash).
      --eth_dag_cache_resv=MEM  Imposta la quantità di memoria della GPU che il miner cercherà di lasciare libera quando lavora con la cache
                              del DAG attiva (vedi --eth_dag_cache).  L'argomento MEM è la quantità di memoria da lasciare libera in
                              mebibyte.  Il valore predefinito è 256.
      --eth_dag_cache_verify    Attiva la lettura e la verifica della cache del dag dopo il completamento della costruzione del dag.  Rileva le situazioni
                              in cui la cache del dag aveva errori di bit e il dag risultante è parzialmente danneggiato.  Lo abbiamo visto
                              succedere sempre più spesso sulle Vega con la crescita del dag.  Quando viene rilevato, viene allocato un nuovo buffer
                              per la cache del dag e la costruzione del dag ricomincia.
      --eth_micro_delay=VAL,VAL,...  Aggiunge un ritardo (misurato in microsecondi) quando si rimette in coda il lavoro sulle gpu.
                              Gli alimentatori più deboli che alimentano molte gpu a volte non reggono lo "slew rate" quando più gpu
                              rimettono in coda il lavoro esattamente nello stesso momento.  Impostarlo ad es. a 32 rende più graduale il passaggio
                              da carico nullo a carico del 100%, abbastanza da ridurre lo slew rate su questi rig.  Il segnale tipico di questo
                              problema sono blocchi totali in cui il rig non risponde più e serve spegnerlo e riaccenderlo, ma possono anche
                              essere normali crash delle gpu.  I valori validi sono 0-256.  Si possono fornire valori per gpu in un elenco separato da virgole.
                              Le gpu senza valori nell'elenco usano il primo valore. I valori predefiniti di questo argomento nel
                              mining ethash ad algoritmo singolo sono:
                                Polaris: 64
                                Vega:    0
                                Navi:    0
      --eth_ignore_abort_fail   Quando l'interruzione di un job fallisce, di solito è perché l'intensità è troppo alta, e il miner
                              quindi la abbassa automaticamente.  Questa opzione _disattiva_ questa logica: mantiene l'intensità e
                              registra invece un avviso nel log.
      --eth_no_job_logs         Elimina tutti i log dei nuovi job ricevuti dai pool.  Si applica a tutte le sessioni di mining della famiglia ethash,
                              cioè in una configurazione dual eth+zil vengono eliminati i log sia del pool eth sia di quello zil.  I job del pool che
                              passano a una nuova epoca vengono comunque registrati.
      --eth_smooth_power=X,Y,...  La pianificazione "smooth power" è stata aggiunta nella 0.10.0 ed è disponibile per tutti i tipi di gpu.
                              In genere è una buona funzione che aggiunge un po' di hashrate e migliora anche la stabilità nella maggior parte
                              dei casi, ed è attiva per default su tutte le gpu.  Tuttavia, ci sono rig che non reagiscono bene e
                              iniziano ad andare in crash.  In questo caso puoi usare questo argomento per controllare la funzione per ogni gpu del rig.
                              I valori validi sono 0 o 1. Per un rig con 5 gpu potresti usare --eth_smooth_power=0,1,1,1,0 per disattivare lo smooth
                              power sulla prima e sull'ultima gpu.  Se non indichi un valore per una gpu, si usa il primo valore dell'elenco.
                              Questo significa che puoi disattivare la funzione per un intero rig con --eth_smooth_power=0.

Opzioni di Progpow (kawpow, firopow):

      --prog_config=CONFIG  Configurazione manuale di progpow per il miner.  CONFIG deve essere nella forma [M][L].
                              Il valore [M] sceglie la modalità, che può essere 'A' o 'B'.
                              La modalità 'B' di solito dà prestazioni migliori, ma è disponibile solo per
                              Vega su linux e Navi (linux o windows).
                              Il valore [L] sceglie l'intensità e il suo intervallo dipende dall'architettura della GPU.
                              Entrambi i valori sono facoltativi, ma se si indica [L], va indicato anche [M].
                              Configurazioni di esempio: --prog_config=A
                                               --prog_config=B750
                              CONFIG può anche essere un elenco di valori di configurazione separati da virgole, ciascuno
                              applicato a ogni GPU. Ad esempio: --prog_config=A,B750,,A288
                              Ogni gpu che non ha una configurazione specifica nell'elenco usa la prima.
      --prog_height=VALUE   Imposta un'altezza di blocco fissa per gli algoritmi progpow a scopo di benchmark.  Il miner passa
                              automaticamente in modalità benchmark.
      --prog_strict         Obbliga il miner a generare sempre kernel rigorosamente esatti.  Per default il miner
                              genera kernel semplificati che usano meno potenza di calcolo, ma possono causare
                              occasionalmente share non valide.
      --prog_dag_slowdown=N  Rallenta la generazione del DAG.  Passa una sola cifra da 0 a 9.  0 significa nessun rallentamento (comportamento <= 0.7.9),
                              1 significa rallentamento minimo, 9 massimo.  Valore predefinito: 4, per un leggero rallentamento.
      --prog_stagger         Vedi --eth_stagger.
      --prog_ramp_up         Vedi --eth_ramp_up.
      --prog_no_stagger      Vedi --eth_no_stagger.
      --prog_no_ramp_up      Vedi --eth_no_ramp_up.
      --prog_micro_tune=X,Y,... Questa opzione attiva una breve sessione di riottimizzazione per ogni nuovo blocco di codice casuale.  È importante
                               perché le gpu Polaris girino alla massima velocità.  Per Vega e Navi di solito non migliora
                               le prestazioni.  La modalità predefinita AUTO la attiva per tutte le gpu Polaris e la disattiva per le altre.
                               L'unico motivo per disattivarla è la stabilità.  Il valore dell'argomento è un
                               elenco di valori separati da virgole, uno per gpu.  Se a una gpu manca un valore, si usa il valore della
                               prima gpu.  Nota che impostare manualmente prog_config disattiva di fatto anche il
                               micro-tuner.  I valori disponibili sono:
                               1 - DISATTIVA il micro-tuning progpow per questa gpu.
                               2 - ATTIVA il micro-tuning progpow per questa gpu.
                               3 - lascia decidere al miner se attivare il micro-tuning (AUTO).
      --prog_hash_report    Attiva l'invio forzato del report dell'hashrate (come per ethash) a tutti i pool.  È un alias di
                               --eth_hash_report=force, che vale anche qui perché progpow ed ethash usano lo stesso
                               protocollo (o protocolli) di pool.

Opzioni di Cryptonight:

      --rig_id              Imposta l'identificativo del rig che viene inviato al pool. Si usa solo per i
                              pool cryptonight.
      --cn_config=CONFIG    Configurazione manuale di cryptonight per il miner.  CONFIG deve essere nella forma
                              [P][I0][M][I1][:xyz], dove [P] è un prefisso facoltativo e [:xyz] è un
                              suffisso facoltativo.  Per [P] è supportato solo il valore 'L', per le GPU
                              di fascia bassa come Lexa/Baffin.  [I0] e [I1] sono i valori di intensità dei thread, che normalmente
                              vanno da 1 a 16, ma per le gpu da 16GB sono possibili valori più alti.  [M] è la
                              modalità, che può essere '.', -', '+' o '*'.  La modalità '.' significa che il miner
                              deve scegliere o cercare la modalità migliore.  La modalità '*' è un buon valore predefinito e
                              _dovrebbe_ essere usata se mini su una Vega 56/64 con timing della memoria modificati.  Le
                              eccezioni a questa regola sono le varianti con pad piccolo (cnv8_trtl e cnv8_upx2), che
                              devono comunque usare '+'. Per le gpu Polaris sono disponibili solo le modalità '-' e '+'.

                              NOTA: in TRM 0.5.0 è stata aggiunta la funzione di auto-tuning, che rende superflua la configurazione manuale
                              delle modalità CN, tranne in rari casi particolari.  Per maggiori informazioni
                              vedi la documentazione sul tuning e le guide incluse nella release.

                              Configurazioni di esempio: --cn_config=15*15:AAA
                                               --cn_config=14-14
                                               --cn_config=L4+3
                              CONFIG può anche essere un elenco di valori di configurazione separati da virgole, ciascuno
                              applicato a ogni GPU. Ad esempio: --cn_config=8-8,16+14:CBB,15*15,14-14
                              Ogni gpu che non ha una configurazione specifica nell'elenco usa la prima
                              configurazione dell'elenco.
      --no_cpu_check        Disattiva la verifica sulla cpu delle share trovate prima di inviarle al pool.
                              Nota: attualmente solo gli algoritmi CN supportano la verifica sulla cpu.
      --no_lean             Disattiva la modalità lean di CN, che avvia gradualmente i thread all'avvio o al riavvio dopo
                              problemi di rete o riduzioni per temperatura delle gpu.
      --no_interleave=DEVS  Elenca i dispositivi gpu su cui non va usata la logica di interleave dei thread CN.
                              L'argomento è un elenco di dispositivi separati da virgole, come per l'opzione -d.
                              Usa questo argomento se alcuni dispositivi ottengono un hashrate peggiore insieme a molti
                              messaggi di log di interleave adjust.
      --alloc_patch=DEVS    Elenca i dispositivi gpu che perdono hashrate tra TRM v0.4.5 e le versioni successive. Con questo
                              argomento si usa una strategia di allocazione della memoria più semplice, e il vecchio hashrate (più alto) dovrebbe
                              tornare. Si può comunque usare la modalità di auto-tuning.
      --auto_tune=MODE      Attiva la modalità di auto-tune all'avvio. Disponibile solo per le varianti CN. MODE deve
                              essere NONE, QUICK o SCAN. La modalità QUICK verifica alcune configurazioni note come buone
                              e termina entro 1 minuto. La modalità SCAN verifica tutte le combinazioni possibili e
                              dura 20-30 minuti. Impostando MODE su NONE si disattiva la funzione di auto-tune. La modalità
                              predefinita è QUICK.
      --auto_tune_runs(=N)  Esegue più passaggi di auto tune, ogni volta riducendo di 1 le unità di pad usate
                              in uno dei thread (15+15 -> 15+14 -> 14+14 -> 14+13 -> ...). Puoi indicare il
                              numero esatto di passaggi o lasciare che il miner scelga un valore predefinito per tipo di gpu (di solito 3-4).
      --auto_tune_exit      Se presente, il miner esce dopo aver completato il processo di auto-tuning. È utile
                              quando vuoi cercare le impostazioni ottimali e poi usare l'argomento della riga di comando risultante
                              stampato dal miner.
      --allow_large_alloc   Se presente, e quando il driver indica che c'è abbastanza vram della GPU disponibile, il miner
                              è più aggressivo nell'allocazione iniziale della memoria. In pratica, questa opzione
                              significa che le GPU Vega su Linux iniziano il processo di auto-tuning da 16*15 invece
                              che da 16*14 o 15*15.

Opzioni di MTP:

      --allow_all_devices   Alcuni algoritmi non si possono minare ad es. su gpu da 4GB. Queste gpu vengono disattivate automaticamente
                              dal miner. Questo argomento ignora questa logica e permette di minare su tutti i dispositivi indicati
                              o rilevati.

Opzioni di X16*:

      --hash_order=VALUE    Imposta un ordine di hash fisso per algoritmi come x16r a scopo di benchmark.
                              Questa impostazione fa passare automaticamente il miner in modalità benchmark.
                              L'ordine di hash standard per il benchmark di x16r è --hash_order=0123456789abcdef.

Opzioni di Nimiq:

      --nimiq_worker=VALUE  Imposta il nome del worker/dispositivo per nimiq da passare al pool (o ai pool).
      --nimiq_no_proxy      Disattiva il proxy Nimiq automatico eseguito come processo separato. Questo significa che
                              l'host e la porta passati al miner devono puntare a un proxy.
      --nimiq_proxy=VALUE   Sostituisce il percorso predefinito del proxy Nimiq. Il predefinito è trm_nimiq_proxy-win.exe
                              e trm_nimiq_proxy-linux nella cartella attuale del miner.
      --nimiq_port=VALUE    Sostituisce la porta locale predefinita (4444) usata per il proxy Nimiq. Si può usare se il tuo
                              sistema usa già la porta 4444 per un altro servizio tcp/ip.

Opzioni di Verthash:

      --verthash_file=FILE  Imposta il nome del file da usare per caricare/salvare il file di dati verthash.  Se questa opzione è
                              indicata quando si usa l'algoritmo verthash, il miner cerca di caricare i dati verthash
                              dal file.  Se il file non esiste, il miner genera i dati verthash
                              e poi li salva nel file per usarli in futuro.  Se questa opzione non è indicata, il
                              miner genera i dati verthash nella memoria di sistema a ogni avvio.
      --verthash_max_uploads=N  Alcune schede madri hanno problemi quando tutte le gpu del rig caricano la tabella verthash
                              nello stesso momento.  Questo argomento limita il numero di gpu che caricano
                              la tabella contemporaneamente all'avvio.  I valori consentiti sono 1-32.  Il valore predefinito è 4.

Opzioni di Autolykos2:

      --autolykos_mem_adjust=N  Imposta la quantità di memoria in MiB che il miner deve lasciare libera quando alloca
                              i buffer della GPU per autolykos.  Il valore predefinito è 384 su linux e 512 su windows.  Per le GPU
                              con monitor collegati, il predefinito aumenta di 512.  In dual mining con ZIL, il
                              valore predefinito aumenta di 1024.  L'opzione si può fornire anche con un elenco di valori separati
                              da virgole, ciascuno applicato a ogni GPU.  Se nell'elenco si indica un valore vuoto,
                              per quella GPU si usa il predefinito.  Se per una GPU non è indicato un valore,
                              si usa il primo valore dell'elenco.  La vram usata deve contenere sia i buffer
                              principali sia l'eventuale buffer precostruito per l'altezza successiva.  Ad esempio:
                                    --autolykos_mem_adjust=256,512,,256
      --autolykos_prebuild=N  Configura la velocità della precostruzione del pad per l'altezza successiva.  Un valore più alto significa una precostruzione più veloce,
                              ma con oscillazioni di consumo maggiori e probabilmente un calo di hashrate maggiore finché la precostruzione è
                              in corso.  I valori validi sono 0-9, dove 0 significa nessuna precostruzione e 9 è la variante più veloce.
                              Il valore predefinito è 3 o 4 a seconda della gpu.  Puoi indicare un solo valore per tutte
                              le gpu, oppure un elenco di valori per gpu separati da virgole.
      --autolykos_slowdown=N  Aggiunge un rallentamento al processo di costruzione del pad.  I valori validi sono 0-100. Il predefinito è 0, nessun
                              rallentamento.
      --autolykos_ignore_diff Ignora la difficoltà inviata dal pool e usa solo il target a 256 bit fornito nei job.
                              Alcuni pool non seguono l'implementazione di riferimento del pool del miner ERGO; in questo caso questo
                              argomento _potrebbe_ aiutare. NOTA: si applica a tutti i pool.

Opzioni del dual mining ZIL:

      --zil_start or --zil  Avvia la configurazione del dual mining ZIL.  Tra questo e il marcatore --zil_end, tutti gli argomenti
                              si applicano al mining ZIL invece che all'algoritmo principale.  Si presume che l'algoritmo principale
                              sia stato configurato negli argomenti precedenti.  L'idea è che tu possa aggiungere una configurazione --zil ... --zil_end
                              a qualsiasi configurazione TRM funzionante e tutto funzioni subito.
                              Questo argomento imposta automaticamente una serie di impostazioni predefinite utili per ZIL:
                               - Copia in cache del DAG ZIL dell'epoca 0.
                               - Regolazione della memoria allocata per l'algoritmo principale per far posto al DAG ZIL.
                               - Scelta della modalità A di ethash per il mining ZIL.
                              La configurazione minima funzionante è indicare solo un pool ZIL che accetti che il miner ignori
                              i job della moneta principale e mini solo durante le finestre ZIL.  Ecco un esempio per ezil.me:
                              --zil -o stratum+tcp://eu.ezil.me:5555 -u <eth wallet>.<zil wallet>.<worker name> -p x --zil_end
                              Per maggiori informazioni leggi la guida al dual mining ZIL inclusa nella release di TRM.
      --zil_end             Indica che la configurazione del mining ZIL è finita e che tutti gli argomenti successivi sono per l'algoritmo
                              principale.  Questo argomento non è strettamente necessario, ma va incluso nelle distribuzioni per il mining, perché
                              l'utente non ha garanzie su quali argomenti la distribuzione aggiungerà automaticamente alla fine della riga
                              di comando.
      --stats_mode=single/dual  Quando si aggiunge il dual mining ZIL, per default l'output delle statistiche viene duplicato per aggiungere le informazioni
                              sul mining ZIL.  Alcuni contesti che analizzano l'output o i file di log di TRM potrebbero confondersi.
                              Per passare all'output predefinito, aggiungi --stats_mode=single.

Opzioni di TON:

      --ton_pool_mode=X     Indica il dialetto di mining TON usato.  Se non è impostato, il miner cerca di dedurre la scelta corretta
                              dall'hostname del pool.  Le opzioni disponibili sono:
                              toncoinpool - usa il protocollo stratum wss per toncoinpool.
                              icemining   - usa il protocollo stratum di ice mining su tcp/ip.
                              tonpool     - usa la versione di tonpool del protocollo stratum di ice mining su wss.
      --wss_force_proxy     Forza l'attivazione del proxy wss automatico, eseguito come processo separato, usato per i pool TON che usano il loro
                              protocollo di mining su wss.  Di solito il miner lo attiva automaticamente, ma se per la connessione si usa un indirizzo IP
                              o un hostname alias, questo argomento potrebbe essere necessario.
      --wss_no_proxy        Disattiva il proxy wss automatico, eseguito come processo separato, usato per i pool TON che usano il loro
                              protocollo di mining su wss. Questo significa che l'host e la porta passati al miner devono puntare
                              a un proxy.
      --wss_proxy=VALUE     Sostituisce il percorso predefinito del proxy wss. Il predefinito è trm_nimiq_proxy-win.exe
                              e trm_nimiq_proxy-linux nella cartella attuale del miner, perché in origine era usato solo per
                              Nimiq.
      --wss_port=VALUE      Sostituisce la porta locale predefinita (4444) usata per il proxy wss. Si può usare se il tuo
                              sistema usa già la porta 4444 per un altro servizio tcp/ip.

Opzioni del dual mining Ethash:

      --ton_start or --ton  Avvia la configurazione del dual mining TON.  Tra questo e il marcatore --ton_end, tutti gli argomenti
                              si applicano al mining TON invece che all'algoritmo principale, di solito ethash.  Si presume che
                              ethash sia stato configurato negli argomenti precedenti.  L'idea è che tu possa aggiungere una configurazione --ton ... --ton_end
                              a qualsiasi configurazione TRM funzionante e tutto funzioni subito.
                              La configurazione minima funzionante è indicare solo un pool TON.  Leggi la guida al mining TON per informazioni sui
                              pool supportati. Ecco un esempio per icemining, con l'indirizzo del suo pool beta:
                              --ton -o stratum+tcp://ton.hashrate.to:4003 -u <ton wallet>.<worker name> -p x --ton_end
                              Per maggiori informazioni leggi la guida al dual mining TON inclusa nella release di TRM.
      --ton_end             Indica che la configurazione del mining TON è finita e che tutti gli argomenti successivi sono per l'algoritmo
                              principale.  Questo argomento non è strettamente necessario, ma va incluso nelle distribuzioni per il mining, perché
                              l'utente non ha garanzie su quali argomenti la distribuzione aggiungerà automaticamente alla fine della riga
                              di comando.
      --kas_start or --kas  Avvia la configurazione del dual mining Kaspa.  Tra questo e il marcatore --kas_end, tutti gli argomenti
                              si applicano al mining Kaspa invece che all'algoritmo principale, di solito ethash.  Si presume che
                              ethash sia stato configurato negli argomenti precedenti.  L'idea è che tu possa aggiungere una configurazione --kas ... --kas_end
                              a qualsiasi configurazione TRM funzionante e tutto funzioni subito.
                              La configurazione minima funzionante è indicare solo un pool Kaspa.  Ecco un esempio:
                              --kas -o stratum+tcp://pool.woolypooly.com:3112 -u <kaspa wallet>.<worker name> -p x --kas_end
      --kas_end             Indica che la configurazione del mining Kaspa è finita e che tutti gli argomenti successivi sono per l'algoritmo
                              principale.  Questo argomento non è strettamente necessario, ma va incluso nelle distribuzioni per il mining, perché
                              l'utente non ha garanzie su quali argomenti la distribuzione aggiungerà automaticamente alla fine della riga
                              di comando.
      --dual_intensity=X,Y,Z,... Questo argomento regola l'intensità del dual mining con un fattore tra 0.0 e 1.0, dove 1.0
                              significa eseguire il più possibile l'algoritmo dual.  Questa opzione è consigliata per ridurre forzatamente il consumo
                              senza abbassare la frequenza del core, cosa che influirebbe anche sull'hashrate ethash.

                              L'argomento si fornisce come singolo valore globale o come elenco di valori per gpu.  Esempi:

                                --dual_intensity=0.75            Tutte le gpu usano il 75% della massima disponibilità possibile delle gpu per TON.
                                --dual_intensity=0.75,1.0,0.5    Valori separati per le prime tre gpu del rig; le gpu rimanenti
                                                                 usano il primo valore, cioè 75%.

      --dual_tuner_step=X   Imposta la dimensione del passo che il dual tuner deve usare per provare diverse intensità della configurazione eth.  Un valore
                              più basso dà risultati più precisi, ma richiede anche più tempo.  I valori validi sono 1,2,4,8,16,32,64.
      --dual_tuner_period=X Imposta il numero di secondi per cui il dual tuner deve girare per ogni configurazione provata.  Il predefinito è 7 sec.
      --dual_tuner_weights=X:Y:Z  Il tuner del dual mining ha bisogno di pesi di punteggio che indichino quanto vale 1 MH/s dell'algoritmo principale e
                              di quello dual.  Nel miner ci sono valori predefiniti che erano validi quando ogni algoritmo è stato implementato
                              e aggiunto, ma con l'andamento dell'hashrate delle reti e dei prezzi di mercato potrebbe servire fornire nuovi valori.
                              Questo argomento fornisce tre valori, tutti numeri positivi:
                                X    Punteggio per 1 MH/s dell'algoritmo principale (di solito ethash).
                                Y    Punteggio per 1 MH/s dell'algoritmo secondario (di solito TON o Kaspa).
                                Z    Costo per 1 W di consumo misurato. Per ora consigliamo di impostarlo a zero.
                              Esempio per ETH+TON:
                                In base al valore relativo stimato a mano: ogni MH/s di ETH vale 100 MH/s di TON/Kaspa
                                --dual_tuner_weights=100:1:0
                                In base ai calcolatori di mining: $0.0437 per 1 MH/s ETH, $0.0005476 per 1 MH/s TON/Kaspa
                                --dual_tuner_weights=0.0437:0.0005476:0

Opzioni FPGA:

      --fpga_devices=LIST   Imposta i dispositivi FPGA da usare tra quelli rilevati. LIST deve essere un elenco separato da virgole di
                              indici di dispositivo o di DNA dei dispositivi, come mostrati da --list_devices.
                                Esempi:     -d 0,1,2,4
                                            -d 40020000013ae32135111111,40020000013ae32135222222,40020000013ae32135333333
                              Se non è indicato, vengono usati tutti i dispositivi FPGA disponibili.
      --fpga_clk_core=LIST  Imposta le frequenze del core dei dispositivi FPGA.  Le frequenze vanno fornite come
                              elenco di valori in megahertz separati da virgole, dove ogni valore si applica a ogni dispositivo FPGA.
                              Se l'elenco è più corto del numero totale di dispositivi, i dispositivi rimanenti usano il
                              primo valore dell'elenco.  Ad esempio --fpga_clk_core=600,620 applica 600MHz a
                              FPGA 0 e 620MHz a FGPA 1.  Se sono presenti dispositivi FPGA 2+, verranno impostati a 600MHz.
      --fpga_clk_mem=LIST   Imposta le frequenze della memoria dei dispositivi FPGA.  Il formato è lo stesso di --fpga_clk_core.
      --fpga_vcc_int=LIST   Imposta la tensione vcc_int sulle schede che lo supportano.  I valori di tensione vanno forniti come
                              elenco di valori in millivolt (mV) separati da virgole, dove ogni valore si applica a ogni scheda.
                              Se l'elenco è più corto del numero totale di dispositivi, i dispositivi rimanenti usano il
                              primo valore dell'elenco.  Ad esempio --fpga_vcc_int=700,800 applica 700mV di vcc_int a
                              FPGA 0 e 800mV di vcc_int a FGPA 1.  Se sono presenti dispositivi FPGA 2+, verranno impostati a 700mV.
      --fpga_vcc_bram=LIST  Imposta la tensione vcc_bram sulle schede che lo supportano.  Il formato è lo stesso di --fpga_vcc_int.
      --fpga_vcc_mem=LIST   Imposta la tensione della memoria/HBM sulle schede che lo supportano.  Il formato è lo stesso di --fpga_vcc_int.
      --fpga_update_fw      Attiva l'aggiornamento del firmware del satellite controller per le schede C1100 con firmware TRM personalizzato,
                              per supportare funzioni come il controllo della tensione in esecuzione. Vengono aggiornate solo le schede selezionate con
                              l'opzione --fpga_devices che non hanno l'ultima versione del firmware.
                              ***** ATTENZIONE: non interrompere il processo di aggiornamento del firmware!            *****
                              *****   Un'interruzione può rendere la scheda inutilizzabile e molto difficile da recuperare. *****
      --fpga_allow_unsafe=LIST Disattiva i limiti di sicurezza predefiniti per gli FPGA indicati.  I dispositivi si indicano con un
                              elenco di valori DNA separati da virgole, ad es. --fpga_allow_unsafe=40020000013ae32135111111
                              ***** ATTENZIONE: superare i limiti di sicurezza può causare DANNI PERMANENTI al dispositivo! *****
      --fpga_tcore_limit=LIST Imposta i limiti soft della temperatura del core dei dispositivi FPGA.  Se la temperatura del core dell'FPGA supera il
                              valore indicato, il miner abbassa le frequenze dell'FPGA per riportare la temperatura del core sotto
                              il valore indicato.  I valori sono in gradi Celsius, con un formato di elenco simile a --fpga_clk_core.
      --fpga_tmem_limit=LIST Imposta i limiti soft della temperatura della memoria dei dispositivi FPGA.  Vedi --fpga_tcore_limits per la descrizione.
      --fpga_ivccint_limit=LIST Imposta i limiti soft di corrente del regolatore di tensione VCCINT.  Vedi --fpga_tcore_limits per la descrizione.
      --fpga_ivccbram_limit=LIST Imposta i limiti soft di corrente del regolatore di tensione VCCBRAM.  Vedi --fpga_tcore_limits per la descrizione.
      --fpga_max_jtag_mhz=XY.Z  Imposta la frequenza massima consentita per la comunicazione jtag dell'fpga.  Il predefinito è 30.0 MHz.
      --fpga_eth_clk_dag=LIST Imposta le frequenze del core dell'FPGA da usare durante la costruzione del DAG Ethash. Per default
                              vengono impostate al 90% della normale frequenza del core. Il formato è lo stesso di --fpga_clk_core.

Download Team Red Miner

0.10.21